
# References

- https://pydantic-docs.helpmanual.io/
- https://python-patterns.guide/
- https://docs.pytest.org/en/7.1.x/getting-started.html#get-started
- https://github.com/samuelcolvin/pydantic
- https://python-poetry.org/docs/pyproject
- https://github.com/wemake-services/wemake-python-package

## Style

- https://code.visualstudio.com/docs/languages/python
- https://code.visualstudio.com/docs/python/linting
- https://code.visualstudio.com/api/language-extensions/snippet-guide
- https://semver.org/
- https://snyk.io/blog/python-poetry-package-manager/

### Taxonomy

- https://github.com/MISP/misp-taxonomies/blob/main/tools/machinetag.py
- https://www.misp-project.org/taxonomies.html#_mapping_of_taxonomies
- https://github.com/MISP/misp-taxonomies
- https://github.com/MISP/misp-taxonomies/blob/main/tools/docs/images/taxonomy-explanation.png

## Development

- vs-code
    - Extensions:
        - snyk
        - flake8
        - isort 


# Ackowledgement

We really appreciate the documentation of https://github.com/VirusTotal/vt-py
